[![Version](https://img.shields.io/badge/version-19.05.0-yellow.svg)](https://github.com/KmolYuan/pyslvs/releases/latest)
[![Build status](https://ci.appveyor.com/api/projects/status/6l1bh1197ncahd0q?svg=true)](https://ci.appveyor.com/project/KmolYuan/pyslvs)
[![Build status](https://img.shields.io/travis/KmolYuan/pyslvs.svg?logo=travis)](https://travis-ci.org/KmolYuan/pyslvs)

# Pyslvs Libraries

A no-GUI module of mechanism synthesis system and a 2D geometric constraint solver.

## Install and Test

Enter directory and execute the Makefile. Then, run the unit test script after compiling.

```bash
python setup.py install
python tests
```

## Documentation

The documentation of Pyslvs is on [Readthedocs](https://pyslvs-ui.readthedocs.io/en/latest/).

If you have any questions, please post on GitHub issue or contact <pyslvs@gmail.com>.
